@@ -54,12 +54,12 @@ AscHintTagStatic asc_hint_tag_list[] =  {
 
 	{ "metainfo-parsing-error",
 	  AS_ISSUE_SEVERITY_ERROR,
-	  "Unable to parse AppStream MetaInfo file `{{fname}}`, the data is likely malformed.<br/>Error: {{error}}"
+	  "Unable to parse AppStream MetaInfo file <code>{{fname}}</code>, the data is likely malformed.<br/>Error: {{error}}"
 	},
 
 	{ "metainfo-no-id",
 	  AS_ISSUE_SEVERITY_ERROR,
-	  "Could not determine an ID for the component in '{{fname}}'. The AppStream MetaInfo file likely lacks an <code>&lt;id/&gt;</code> tag.<br/>"
+	  "Could not determine an ID for the component in <code>{{fname}}</code>. The AppStream MetaInfo file likely lacks an <code>&lt;id/&gt;</code> tag.<br/>"
           "The identifier tag is essential for AppStream metadata, and must not be missing."
 	},
 
@@ -80,6 +80,11 @@ AscHintTagStatic asc_hint_tag_list[] =  {
 	  "<code>type=</code> property of the component root-node in the MetaInfo XML file does not contain a spelling mistake."
 	},
 
+	{ "file-read-error",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  "Unable to read data from file <code>{{fname}}</code>: {{msg}}",
+	},
+
 	{ "desktop-file-error",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  "Unable to read data from .desktop file: {{msg}}",
@@ -119,6 +124,49 @@ AscHintTagStatic asc_hint_tag_list[] =  {
 	  "See <a href=\"https://standards.freedesktop.org/desktop-entry-spec/latest/ar01s06.html\">the specification</a> for details."
 	},
 
+	{ "missing-launchable-desktop-file",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  "The MetaInfo file references a .desktop file with ID '{{desktop_id}}' in its <code>launchable</code> tag, but the file "
+	  "was not found in the same source tree. In order to be able to launch the software once it was installed, please place the "
+	  "MetaInfo file and its .desktop files in the same package."
+	},
+
+	{ "translation-status-error",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  "Unable to read translation status data: {{msg}}",
+	},
+
+	{ "translations-not-found",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  "Unable to add languages information, even though a <code>translation</code> tag was present in the MetaInfo file. "
+	  "Please check that its value is set correctly, and all locale files are placed in the right directories "
+	  "(e.g. <code>/usr/share/locale/*/LC_MESSAGES/</code> for Gettext .mo files)."
+	},
+
+	{ "icon-not-found",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  "The icon <em>{{icon_fname}}</em> was not found in the archive. This issue can have multiple reasons, "
+	  "like the icon being in a wrong directory or not being available in a suitable size (at least 64x64px). "
+	  "To make the icon easier to find, place it in <code>/usr/share/icons/hicolor/&lt;size&gt;/apps</code> and ensure the <code>Icon=</code> value"
+	  "of the desktop-entry file is set correctly."
+	},
+
+	{ "no-stock-icon",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  "The component has no stock icon set, even though it requires one (or a `local` icon) to be valid."
+	},
+
+	{ "icon-write-error",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  "Unable to store icon <code>{{fname}}</code>: {{msg}}"
+	},
+
+	{ "duplicate-component",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  "A component with this ID already exists. AppStream IDs must be unique, any subsequent components "
+	  "have been ignored. Please resolve the ID conflict!"
+	},
+
 	{ NULL, AS_ISSUE_SEVERITY_UNKNOWN, NULL }
 };
 
