@@ -501,9 +501,7 @@ as_validate_is_secure_url (const gchar *str)
 static void
 as_validator_check_children_quick (AsValidator *validator, xmlNode *node, const gchar *allowed_tagname, gboolean allow_empty)
 {
-	xmlNode *iter;
-
-	for (iter = node->children; iter != NULL; iter = iter->next) {
+	for (xmlNode *iter = node->children; iter != NULL; iter = iter->next) {
 		const gchar *node_name;
 		/* discard spaces */
 		if (iter->type != XML_ELEMENT_NODE)
@@ -551,9 +549,7 @@ as_validator_check_nolocalized (AsValidator *validator, xmlNode* node, const gch
 static void
 as_validator_check_description_paragraph (AsValidator *validator, xmlNode *node)
 {
-	xmlNode *iter;
-
-	for (iter = node->children; iter != NULL; iter = iter->next) {
+	for (xmlNode *iter = node->children; iter != NULL; iter = iter->next) {
 		const gchar *node_name;
 		/* discard spaces */
 		if (iter->type != XML_ELEMENT_NODE)
@@ -576,9 +572,7 @@ as_validator_check_description_paragraph (AsValidator *validator, xmlNode *node)
 static void
 as_validator_check_description_enumeration (AsValidator *validator, xmlNode *node)
 {
-	xmlNode *iter;
-
-	for (iter = node->children; iter != NULL; iter = iter->next) {
+	for (xmlNode *iter = node->children; iter != NULL; iter = iter->next) {
 		const gchar *node_name;
 		/* discard spaces */
 		if (iter->type != XML_ELEMENT_NODE)
@@ -606,7 +600,6 @@ as_validator_check_description_enumeration (AsValidator *validator, xmlNode *nod
 static void
 as_validator_check_description_tag (AsValidator *validator, xmlNode* node, AsFormatStyle mode, gboolean main_description)
 {
-	xmlNode *iter;
 	gboolean first_paragraph = TRUE;
 
 	if (mode == AS_FORMAT_STYLE_METAINFO) {
@@ -616,7 +609,7 @@ as_validator_check_description_tag (AsValidator *validator, xmlNode* node, AsFor
 						(const gchar*) node->name);
 	}
 
-	for (iter = node->children; iter != NULL; iter = iter->next) {
+	for (xmlNode *iter = node->children; iter != NULL; iter = iter->next) {
 		const gchar *node_name = (gchar*) iter->name;
 		g_autofree gchar *node_content = (gchar*) xmlNodeGetContent (iter);
 
@@ -922,8 +915,7 @@ as_validator_validate_update_contact (AsValidator *validator, xmlNode *uc_node)
 static void
 as_validator_check_screenshots (AsValidator *validator, xmlNode *node, AsComponent *cpt)
 {
-	xmlNode *iter;
-	for (iter = node->children; iter != NULL; iter = iter->next) {
+	for (xmlNode *iter = node->children; iter != NULL; iter = iter->next) {
 		xmlNode *iter2;
 		gboolean image_found = FALSE;
 		gboolean video_found = FALSE;
@@ -943,8 +935,8 @@ as_validator_check_screenshots (AsValidator *validator, xmlNode *node, AsCompone
 						"invalid-child-tag-name",
 						/* TRANSLATORS: An invalid XML tag was found, "Found" refers to the tag name found, "Allowed" to the permitted name. */
 						_("Found: %s - Allowed: %s"),
-						(const gchar*) iter->name),
-						"screenshot";
+						(const gchar*) iter->name,
+						"screenshot");
 		}
 
 		for (iter2 = iter->children; iter2 != NULL; iter2 = iter2->next) {
@@ -1037,8 +1029,8 @@ as_validator_check_screenshots (AsValidator *validator, xmlNode *node, AsCompone
 							"invalid-child-tag-name",
 							/* TRANSLATORS: An invalid XML tag was found, "Found" refers to the tag name found, "Allowed" to the permitted name. */
 							_("Found: %s - Allowed: %s"),
-							(const gchar*) iter2->name),
-							"caption; image; video";
+							(const gchar*) iter2->name,
+							"caption; image; video");
 			}
 		}
 
@@ -1058,9 +1050,7 @@ as_validator_check_screenshots (AsValidator *validator, xmlNode *node, AsCompone
 static void
 as_validator_check_requires_recommends (AsValidator *validator, xmlNode *node, AsComponent *cpt, AsRelationKind kind)
 {
-	xmlNode *iter;
-
-	for (iter = node->children; iter != NULL; iter = iter->next) {
+	for (xmlNode *iter = node->children; iter != NULL; iter = iter->next) {
 		const gchar *node_name;
 		g_autofree gchar *content = NULL;
 		g_autofree gchar *version = NULL;
@@ -1180,9 +1170,7 @@ as_validator_check_requires_recommends (AsValidator *validator, xmlNode *node, A
 static void
 as_validator_check_provides (AsValidator *validator, xmlNode *node, AsComponent *cpt)
 {
-	xmlNode *iter;
-
-	for (iter = node->children; iter != NULL; iter = iter->next) {
+	for (xmlNode *iter = node->children; iter != NULL; iter = iter->next) {
 		const gchar *node_name;
 		g_autofree gchar *node_content = NULL;
 		if (iter->type != XML_ELEMENT_NODE)
@@ -1931,6 +1919,25 @@ as_validator_validate_component_node (AsValidator *validator, AsContext *ctx, xm
 			}
 			release_prev = release;
 		}
+	} else {
+		/* we have no release information! */
+		AsComponentKind kind = as_component_get_kind (cpt);
+		if (kind == AS_COMPONENT_KIND_DESKTOP_APP ||
+		    kind == AS_COMPONENT_KIND_CONSOLE_APP) {
+			/* show an info about missing age rating for application-type components */
+			as_validator_add_issue (validator, NULL, "releases-info-missing", NULL);
+		}
+	}
+
+	/* check content_rating */
+	if (as_component_get_content_ratings (cpt)->len == 0) {
+		AsComponentKind kind = as_component_get_kind (cpt);
+		if (kind == AS_COMPONENT_KIND_DESKTOP_APP ||
+		    kind == AS_COMPONENT_KIND_CONSOLE_APP ||
+		    kind == AS_COMPONENT_KIND_WEB_APP) {
+			/* show an info about missing age rating for application-type components */
+			as_validator_add_issue (validator, NULL, "content-rating-missing", NULL);
+		}
 	}
 
 	as_validator_clear_current_cpt (validator);
@@ -2082,11 +2089,10 @@ as_validator_validate_bytes (AsValidator *validator, GBytes *metadata)
 		if (cpt != NULL)
 			g_object_unref (cpt);
 	} else if (g_strcmp0 ((gchar*) root->name, "components") == 0) {
-		xmlNode *iter;
 		const gchar *node_name;
 
 		as_context_set_style (ctx, AS_FORMAT_STYLE_COLLECTION);
-		for (iter = root->children; iter != NULL; iter = iter->next) {
+		for (xmlNode *iter = root->children; iter != NULL; iter = iter->next) {
 			/* discard spaces */
 			if (iter->type != XML_ELEMENT_NODE)
 				continue;
